Documentation
¶
Overview ¶
Package snmp provides an implementation of the SNMP specification.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Timeout = 30
Timeout is the number of seconds to use for conn.SetReadDeadline
Functions ¶
Types ¶
type Rows ¶
type Rows struct {
// contains filtered or unexported fields
}
Rows is the result of a walk. Its cursor starts before the first row of the result set. Use Next to advance through the rows:
rows, err := snmp.Walk(host, community, "ifName")
...
for rows.Next() {
var name []byte
err = rows.Scan(&name)
...
}
err = rows.Err() // get any error encountered during iteration
...
type SNMP ¶
type SNMP struct {
// Community is the SNMP community.
Community string
// Addr is the UDP address of the SNMP host.
Addr *net.UDPAddr
}
SNMP performs SNMPv2 requests as defined by RFC 3416.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package asn1 implements parsing of DER-encoded ASN.1 data structures, as defined in ITU-T Rec X.690.
|
Package asn1 implements parsing of DER-encoded ASN.1 data structures, as defined in ITU-T Rec X.690. |
|
Package mib parses modules of the virtual management information store.
|
Package mib parses modules of the virtual management information store. |
Click to show internal directories.
Click to hide internal directories.